=====================================
Utility functions for HTML generation
=====================================

.. automodule:: abed.html.utils
    :members:
    :undoc-members:
    :show-inheritance:
